<h3
    <?php echo e($attributes->class(['fi-no-notification-title text-sm font-medium text-gray-950 dark:text-white'])); ?>

>
    <?php echo e($slot); ?>

</h3>
<?php /**PATH C:\justineganteng\pemograman_new\projek\laravel\sistem_inventaris_penduduk_raksajaya\vendor\filament\notifications\src\/../resources/views/components/title.blade.php ENDPATH**/ ?>